@@ -68,6 +68,8 @@ class ODPFlowFactory:
         Returns:
             an ODPFlow instance
         """
+        if "flow-dump from pmd on cpu core" in odp_string:
+            return None
 
         sections = []
 
@@ -240,7 +242,7 @@ class ODPFlowFactory:
                 )
             ),
             "pop_nsh": decode_flag,
-            "tnl_pop": decode_int,
+            "tnl_pop": decode_default,
             "ct_clear": decode_flag,
             "ct": nested_kv_decoder(
                 KVDecoders(
@@ -305,7 +307,7 @@ class ODPFlowFactory:
             "tnl_push": nested_kv_decoder(
                 KVDecoders(
                     {
-                        "tnl_port": decode_int,
+                        "tnl_port": decode_default,
                         "header": nested_kv_decoder(
                             KVDecoders(
                                 {
@@ -398,7 +400,7 @@ class ODPFlowFactory:
                                 }
                             )
                         ),
-                        "out_port": decode_int,
+                        "out_port": decode_default,
                     }
                 )
             )
